package cn.minestar.agriculture.mapper;

import cn.minestar.agriculture.entity.WxMiniUserLabel;

import java.util.List;

/**
 * 【请填写功能名称】Mapper接口
 * 
 * @author www.minestar.cn/
 * @date 2021-08-12
 */
public interface WxMiniUserLabelMapper 
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】ID
     * @return 【请填写功能名称】
     */
    public WxMiniUserLabel selectWxMiniUserLabelById(Long id);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param wxMiniUserLabel 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<WxMiniUserLabel> selectWxMiniUserLabelList(WxMiniUserLabel wxMiniUserLabel);

    /**
     * 新增【请填写功能名称】
     * 
     * @param wxMiniUserLabel 【请填写功能名称】
     * @return 结果
     */
    public int insertWxMiniUserLabel(WxMiniUserLabel wxMiniUserLabel);

    /**
     * 修改【请填写功能名称】
     * 
     * @param wxMiniUserLabel 【请填写功能名称】
     * @return 结果
     */
    public int updateWxMiniUserLabel(WxMiniUserLabel wxMiniUserLabel);

    /**
     * 删除【请填写功能名称】
     * 
     * @param id 【请填写功能名称】ID
     * @return 结果
     */
    public int deleteWxMiniUserLabelById(Long id);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteWxMiniUserLabelByIds(Long[] ids);
}
